BFGraph: CompressedCoverage_t< void > Struct Template Reference

BFGraph

Public Member Functions | Data Fields
CompressedCoverage_t< void > Struct Template Reference

## Public Member Functions
| CompressedCoverage_t (size_t sz=0, bool full=false)
const void * | getData () const
void * | getData ()
void | setData (const void *const data_)

## Data Fields
CompressedCoverage | ccov

The documentation for this struct was generated from the following file:

- src/CompressedCoverage.hpp